pub enum ProofError {
VerificationError,
FormatError,
WrongNumBlindingFactors,
InvalidBitsize,
InvalidAggregation,
InvalidGeneratorsLength,
InvalidInputLength,
ProvingError(MPCError),
}Expand description
Represents an error in proof creation, verification, or parsing.
Variants
VerificationError
This error occurs when a proof failed to verify.
FormatError
This error occurs when the proof encoding is malformed.
WrongNumBlindingFactors
This error occurs during proving if the number of blinding factors does not match the number of values.
InvalidBitsize
This error occurs when attempting to create a proof with bitsize other than \(8\), \(16\), \(32\), or \(64\).
InvalidAggregation
This error occurs when attempting to create an aggregated proof with non-power-of-two aggregation size.
InvalidGeneratorsLength
This error occurs when there are insufficient generators for the proof.
InvalidInputLength
This error occurs when inputs are the incorrect length for the proof.
ProvingError(MPCError)
This error results from an internal error during proving.
The single-party prover is implemented by performing multiparty computation with ourselves. However, because the MPC protocol is not exposed by the single-party API, we consider its errors to be internal errors.